/*
 * $Id: mxf_avid_labels_and_keys.h,v 1.2 2008/10/23 14:01:55 philipn Exp $
 *
 * Avid labels, keys, etc.
 *
 * Copyright (C) 2006  Philip de Nier <philipn@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
#ifndef __MXF_AVID_LABELS_AND_KEYS_H__
#define __MXF_AVID_LABELS_AND_KEYS_H__


#ifdef __cplusplus
extern "C" 
{
#endif



/*
 *
 * Picture essence coding compression labels
 *
 */
 

/* Avid MJPEG labels observed in files created by Media Composer 2.1.x */
static const mxfUL MXF_CMDEF_L(AvidMJPEG21) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x02, 0x01, 0x02, 0x01, 0x01, 0x08};
static const mxfUL MXF_CMDEF_L(AvidMJPEG31) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x02, 0x01, 0x02, 0x01, 0x01, 0x06};
static const mxfUL MXF_CMDEF_L(AvidMJPEG101) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x02, 0x01, 0x02, 0x01, 0x01, 0x04};
static const mxfUL MXF_CMDEF_L(AvidMJPEG101m) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x02, 0x01, 0x02, 0x01, 0x04, 0x02};
static const mxfUL MXF_CMDEF_L(AvidMJPEG151s) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x02, 0x01, 0x02, 0x01, 0x02, 0x02};
static const mxfUL MXF_CMDEF_L(AvidMJPEG201) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x02, 0x01, 0x02, 0x01, 0x01, 0x02};

/* DV100 labels observed in files by Media Composer 2.6 */
static const mxfUL MXF_CMDEF_L(DV1080i50) =
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x04, 0x01, 0x02, 0x02, 0x02, 0x02, 0x06, 0x00};

/* DV100 720p50 is not supported by Media Composer 2.6, labels found in P2 created media */
static const mxfUL MXF_CMDEF_L(DV720p50) =
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x04, 0x01, 0x02, 0x02, 0x02, 0x02, 0x08, 0x00};



/*
 *
 * Essence container labels
 *
 */
 
static const mxfUL MXF_EC_L(AvidDV25ClipWrappedEssenceContainer) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x03, 0x01, 0x02, 0x01, 0x00, 0x00};
    
static const mxfUL MXF_EC_L(AvidMJPEGClipWrapped) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x04, 0x03, 0x01, 0x02, 0x01, 0x00, 0x00};

static const mxfUL MXF_EC_L(AvidAAFKLVEssenceContainer) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x01, 0x01, 0x01, 0xff, 0x4b, 0x46, 0x41, 0x41, 0x00, 0x0d, 0x4d, 0x4f};

/* To be identical to the Avid don't use MXF_EC_L(D10_50_625_50_picture_only)
 etc since they use regver=2 while Avid uses regver=1 */
static const mxfUL MXF_EC_L(IMX30) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0d, 0x01, 0x03, 0x01, 0x02, 0x01, 0x05, 0x7f};
static const mxfUL MXF_EC_L(IMX40) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0d, 0x01, 0x03, 0x01, 0x02, 0x01, 0x03, 0x7f};
static const mxfUL MXF_EC_L(IMX50) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0d, 0x01, 0x03, 0x01, 0x02, 0x01, 0x01, 0x7f};

/* DV100 labels observed in files by Media Composer 2.6 */
static const mxfUL MXF_EC_L(DV1080i50ClipWrapped) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0d, 0x01, 0x03, 0x01, 0x02, 0x02, 0x61, 0x02};

/* DV100 720p50 is not supported by Media Composer 2.6, labels found in P2 created media */
static const mxfUL MXF_EC_L(DV720p50ClipWrapped) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x04, 0x01, 0x01, 0x01, 0x0d, 0x01, 0x03, 0x01, 0x02, 0x02, 0x63, 0x02};



/*
 *
 * Essence element keys
 *
 */
 
static const mxfKey MXF_EE_K(AvidMJPEGClipWrapped) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x01, 0x02, 0x01, 0x01, 0x0e, 0x04, 0x03, 0x01, 0x15, 0x01, 0x01, 0x01};

/* DV100 labels observed in files by Media Composer 2.6 */
static const mxfKey MXF_EE_K(DV1080i50) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x01, 0x02, 0x01, 0x01, 0x0d, 0x01, 0x03, 0x01, 0x18, 0x01, 0x02, 0x01};

/* DV100 720p50 is not supported by Media Composer 2.6, labels found in P2 created media */
static const mxfKey MXF_EE_K(DV720p50) = 
    {0x06, 0x0e, 0x2b, 0x34, 0x01, 0x02, 0x01, 0x01, 0x0d, 0x01, 0x03, 0x01, 0x18, 0x01, 0x02, 0x01};

static const mxfKey MXF_EE_K(DNxHD) = MXF_DNXHD_PICT_EE_K(0x01, 0x06, 0x01)

static const mxfKey MXF_EE_K(DVClipWrapped) = MXF_DV_EE_K(0x01, MXF_DV_CLIP_WRAPPED_EE_TYPE, 0x01);
    
static const mxfKey MXF_EE_K(BWFClipWrapped) = MXF_AES3BWF_EE_K(0x01, MXF_BWF_CLIP_WRAPPED_EE_TYPE, 0x01);

static const mxfKey MXF_EE_K(AES3ClipWrapped) = MXF_AES3BWF_EE_K(0x01, MXF_AES3_CLIP_WRAPPED_EE_TYPE, 0x01);

static const mxfKey MXF_EE_K(UncClipWrapped) = MXF_UNC_EE_K(0x01, MXF_UNC_CLIP_WRAPPED_EE_TYPE, 0x01);

/* IMX (D10) labels observed in files by Media Composer 2.6 */
static const mxfKey MXF_EE_K(IMX) = MXF_D10_PICTURE_EE_K(0x01);



/*
 *
 * Avid CDCIDescriptor::ResolutionID
 *
 */
 
static const uint32_t g_AvidMJPEG21_ResolutionID = 0x4c;    /* 76 */
static const uint32_t g_AvidMJPEG31_ResolutionID = 0x4d;    /* 77 */
static const uint32_t g_AvidMJPEG101_ResolutionID = 0x4b;   /* 75 */
static const uint32_t g_AvidMJPEG101m_ResolutionID = 0x6e;  /* 110 */
static const uint32_t g_AvidMJPEG151s_ResolutionID = 0x4e;  /* 78 */
static const uint32_t g_AvidMJPEG201_ResolutionID = 0x52;   /* 82 */


    
/*
 *
 * Avid extensions metadata keys
 *
 */
 
static const mxfKey g_AvidObjectDirectory_key = 
    {0x96, 0x13, 0xb3, 0x8a, 0x87, 0x34, 0x87, 0x46, 0xf1, 0x02, 0x96, 0xf0, 0x56, 0xe0, 0x4d, 0x2a};

static const mxfKey g_AvidMetadataRoot_key = 
    {0x80, 0x53, 0x08, 0x00, 0x36, 0x21, 0x08, 0x04, 0xb3, 0xb3, 0x98, 0xa5, 0x1c, 0x90, 0x11, 0xd4};

    
    
#ifdef __cplusplus
}
#endif


#endif


